@@ -74,8 +74,9 @@
 //! - [`fallback`](Parser::fallback) and [`fallback_with`](Parser::fallback_with) - return a
 //!   different value if parser fails to find what it is looking for. Generated help for former
 //!   can be updated to include default value using
-//!   [`display_fallback`](ParseFallback::display_fallback) and
-//!   [`debug_fallback`](ParseFallback::debug_fallback) .
+//!   [`display_fallback`](ParseFallback::display_fallback),
+//!   [`debug_fallback`](ParseFallback::debug_fallback), or
+//!   [`format_fallback`](ParseFallback::format_fallback).
 //! - [`optional`](Parser::optional) - return `None` if value is missing instead of failing, see
 //!   also [`catch`](ParseOptional::catch) .
 //! - [`many`](Parser::many), [`some`](Parser::some) and [`collect`](Parser::collect) - collect
@@ -399,7 +400,6 @@ pub use bpaf_derive::Bpaf;
 ///     CD { c: u32, d: u32 }
 /// }
 /// ```
-
 #[macro_export]
 macro_rules! construct {
     // construct!(Enum::Cons { a, b, c })
@@ -679,7 +679,6 @@ pub trait Parser<T> {
     /// [`many`](Parser::many) also collects results to a vector but succeeds with
     /// no matching values. [`collect`](Parser::collect) collects results into a [`FromIterator`]
     /// structure
-
     #[must_use]
     fn some(self, message: &'static str) -> ParseSome<Self>
     where
@@ -851,10 +850,11 @@ pub trait Parser<T> {
     ///
     /// # See also
     /// [`fallback_with`](Parser::fallback_with) would allow to try to fallback to a value that
-    /// comes from a failing computation such as reading a file. By default fallback value will
-    /// not be shown in the `--help` output, you can change that by using
-    /// [`display_fallback`](ParseFallback::display_fallback) and
-    /// [`debug_fallback`](ParseFallback::debug_fallback).
+    /// comes from a failing computation such as reading a file. By default, the fallback value will
+    /// not be shown in the `--help` output; you can change that by using
+    /// [`display_fallback`](ParseFallback::display_fallback),
+    /// [`debug_fallback`](ParseFallback::debug_fallback), or
+    /// [`format_fallback`](ParseFallback::format_fallback).
     #[must_use]
     fn fallback(self, value: T) -> ParseFallback<Self, T>
     where
@@ -877,9 +877,11 @@ pub trait Parser<T> {
     ///
     /// # See also
     /// [`fallback`](Parser::fallback) implements similar logic expect that failures aren't expected.
-    /// By default fallback value will not be shown in the `--help` output, you can change that by using
-    /// [`display_fallback`](ParseFallbackWith::display_fallback) and
-    /// [`debug_fallback`](ParseFallbackWith::debug_fallback).
+    /// By default, the fallback value will
+    /// not be shown in the `--help` output; you can change that by using
+    /// [`display_fallback`](ParseFallbackWith::display_fallback),
+    /// [`debug_fallback`](ParseFallbackWith::debug_fallback), or
+    /// [`format_fallback`](ParseFallbackWith::format_fallback).
     #[must_use]
     fn fallback_with<F, E>(self, fallback: F) -> ParseFallbackWith<T, Self, F, E>
     where
@@ -1210,8 +1212,6 @@ pub trait Parser<T> {
 
     /// Create a boxed representation for a parser
     ///
-    ///
-
     /// The boxed parser doesn't expose internal representation in its type and allows to return
     /// of different parsers in different conditional branches
     ///
@@ -1411,7 +1411,7 @@ where
     ParseCommand {
         longs: vec![name],
         shorts: Vec::new(),
-        help: subparser.short_descr().map(Into::into),
+        help: subparser.short_descr(),
         subparser,
         adjacent: false,
     }
