@@ -516,6 +516,20 @@ where
     }
 }
 
+/// An implementation detail for [`ParseFallback::format_fallback`] and
+/// [`ParseFallbackWith::format_fallback`], to allow for custom fallback formatting.
+struct DisplayWith<'a, T, F>(&'a T, F);
+
+impl<'a, T, F: Fn(&'a T, &mut std::fmt::Formatter<'_>) -> std::fmt::Result> std::fmt::Display
+    for DisplayWith<'a, T, F>
+{
+    #[inline(always)]
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        let Self(value, display) = self;
+        display(value, f)
+    }
+}
+
 impl<P, T: std::fmt::Display> ParseFallback<P, T> {
     /// Show [`fallback`](Parser::fallback) value in `--help` using [`Display`](std::fmt::Display)
     /// representation
@@ -540,6 +554,21 @@ impl<P, T: std::fmt::Debug> ParseFallback<P, T> {
     }
 }
 
+impl<P, T> ParseFallback<P, T> {
+    /// Show [`fallback`](Parser::fallback) value in `--help` using the provided formatting
+    /// function.
+    ///
+    #[cfg_attr(not(doctest), doc = include_str!("docs2/format_fallback.md"))]
+    #[must_use]
+    pub fn format_fallback(
+        mut self,
+        format: impl Fn(&T, &mut std::fmt::Formatter<'_>) -> std::fmt::Result,
+    ) -> Self {
+        self.value_str = format!("[default: {}]", DisplayWith(&self.value, format));
+        self
+    }
+}
+
 impl<P, T: std::fmt::Display, F, E> ParseFallbackWith<T, P, F, E>
 where
     F: Fn() -> Result<T, E>,
@@ -578,6 +607,26 @@ where
     }
 }
 
+impl<P, T, F, E> ParseFallbackWith<T, P, F, E>
+where
+    F: Fn() -> Result<T, E>,
+{
+    /// Show [`fallback_with`](Parser::fallback_with) value in `--help` using the provided
+    /// formatting function.
+    ///
+    #[cfg_attr(not(doctest), doc = include_str!("docs2/format_fallback_with.md"))]
+    #[must_use]
+    pub fn format_fallback(
+        mut self,
+        format: impl Fn(&T, &mut std::fmt::Formatter<'_>) -> std::fmt::Result,
+    ) -> Self {
+        if let Ok(val) = (self.fallback)() {
+            self.value_str = format!("[default: {}]", DisplayWith(&val, format));
+        }
+        self
+    }
+}
+
 /// Parser fails with a message if check returns false, created with [`guard`](Parser::guard).
 pub struct ParseGuard<P, F> {
     pub(crate) inner: P,
@@ -901,7 +950,6 @@ where
 
 impl<T> ParseCon<T> {
     #[must_use]
-
     /// Automagically restrict the inner parser scope to accept adjacent values only
     ///
     /// `adjacent` can solve surprisingly wide variety of problems: sequential command chaining,
